@@ -1,20 +1,20 @@
-/* $Id: glibmm.h 508 2008-01-12 19:50:43Z murrayc $ */
+/* $Id$ */
 
 /* glibmm - a C++ wrapper for the GLib toolkit
  *
  * Copyright 2002 The gtkmm Development Team
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
@@ -25,6 +25,7 @@
 #include <glibmmconfig.h>
 //#include <glibmm/i18n.h> //This must be included by the application, after system headers such as <iostream>.
 #include <glibmm/arrayhandle.h>
+#include <glibmm/checksum.h>
 #include <glibmm/class.h>
 #include <glibmm/containerhandle_shared.h>
 #include <glibmm/convert.h>
@@ -45,6 +46,7 @@
 #include <glibmm/markup.h>
 #include <glibmm/miscutils.h>
 #include <glibmm/module.h>
+#include <glibmm/nodetree.h>
 #include <glibmm/objectbase.h>
 #include <glibmm/object.h>
 #include <glibmm/optioncontext.h>
@@ -69,6 +71,7 @@
 #include <glibmm/uriutils.h>
 #include <glibmm/ustring.h>
 #include <glibmm/value.h>
+#include <glibmm/valuearray.h>
 #include <glibmm/wrap.h>
 
 #endif /* _GLIBMM_H */
